/********************************************************************************************************
Macro Name:   binDesign.sas
Author:       Matthew Psioda
Affiliation:  Department of Biostatistics, University of North Carolina at Chapel Hill
    
**** Program Summary:
     This program calculates the power/type I error rates based on simulated binomial studies but
     not using any prior information

**** Needed Macro Variables;
    (1) nSamp           = <integer> number of MCMC samples
    (2) gamma           = <double> lower bound for posterior probability decision rule
    (3) expDelta        = <double> non-inferiority margin on probability scale
    (4) dsIn            = <libname.dataset> dataset containing simulation studies for analysis
    (5) dsOut           = <libname.dataset> dataset containing empirical power/type one error rates
*********************************************************************************************************/

%macro BinDesign(nSamp=10000,gamma=0.95,expDelta=0.05,dsIn=simStudy,dsOut=simStudyResults);

proc IML;
start logistic(x);
 return( exp(x) / (1+exp(x)));
finish;
start logit(x);
 return( log(x) - log(1-x) );
finish;

expDelta = &expDelta.;
gamma = &gamma.;
nSamp = &nSamp.;

 use &dsIn.;
 read all var _all_;

 mu1 = J(nSamp,1,0);
 mu2 = J(nSamp,1,0);
 
 studyRepNum = max(studyRep);

 PostProb = J(studyRepNum,1,0);

 do j = 1 to studyRepNum;
  call randgen(mu1,'beta',yt[j],nt[j]-yt[j]); 
  call randgen(mu2,'beta',yc[j],nc[j]-yc[j]);

   diff = mu1-mu2;

   indicator = (diff < expDelta)[+]/nSamp;
   PostProb[j] = (indicator > gamma);
 end;

 rejRate = PostProb[+]/studyRepNum;

 dat = pi_t[1]||pi_c[1]||nt[1]||nc[1]||rejRate;

 create &dsOut. from dat[c={"pi_t" "pi_c" "nt" "nc" "RejRate" }];
  append from dat;
 close &dsOut.;

quit;;

data &dsOut.;
 set &dsOut.;
  label RejRate = 'Empirical Null Hypothesis Rejection Rate';
run;
%mend;
