/********************************************************************************************************
Macro Name:   binDesignPP.sas
Author:       Matthew Psioda
Affiliation:  Department of Biostatistics, University of North Carolina at Chapel Hill
    
**** Program Summary:
     This program calculates the power/type I error rates based on simulated binomial studies and using the power prior

**** Needed Macro Variables;
    (1) MCMCOptions     = <text> options for proc MCMC - ex: %str(nbi=500 nmc=20000 nthin=1)
    (2) gamma           = <double> lower bound for posterior probability decision rule
    (3) expDelta        = <double> non-inferiority margin on probability scale
    (4) dsIn            = <libname.dataset> dataset containing simulation studies for analysis
    (5) dsInPP          = <libname.dataset> dataset containing historical studies (sufficient statistics)
    (6) dsOut           = <libname.dataset> dataset containing empirical power/type one error rates
*********************************************************************************************************/
%macro BinDesignPP(MCMCOptions=,gamma=0.95,expDelta=0.041,dsIn=simStudy,dsInPP=powerPrior,dsOut=Power);

data _null_;
 set  &dsInPP.;
 call symput('hc_k',strip(put(_n_,best.)));
run;

ods output PostSummaries=&dsOut._PostSummaries;
proc mcmc data = simStudy(drop=pi:) monitor=(pi_c pi_t diff indicator) &mcmcOptions. plots=(none) statistics=summary;
 by StudyRep;

 array hc_n[&hc_k.] / nosymbols;
 array hc_y[&hc_k.] / nosymbols;
 array hc_a0[&hc_k.] / nosymbols;

  begincnst;
   rc = read_array("&dsInPP.", hc_n, "n");
   rc = read_array("&dsInPP.", hc_y, "y");
   rc = read_array("&dsInPP.", hc_a0, "a0");

   term1 = 0;
   term2 = 0;
   term3 = 0;
   do k = 1 to &hc_k.;
     term1 = term1 + hc_a0[k]*hc_y[k];
     term2 = term2 + hc_a0[k]*(hc_n[k]-hc_y[k]);
     term3 = term3 + hc_a0[k]*hc_n[k];
   end;

   logBeta = lgamma(term1)+lgamma(term2)-lgamma(term3);
  endcnst;


  parms pi_t 0.5;
  parms mu_c 0 / slice;

  prior pi_t ~ beta(yt,nt-yt);

  logPowerPrior = mu_c*term1 - logBeta - term3*log(1+exp(mu_c));
  prior mu_c ~ general(logPowerPrior);

  pi_c = logistic(mu_c);

  diff      = pi_t-pi_c;
  indicator = (diff < &expDelta);

  model yc ~ binomial(nc,pi_c);
run;

data &dsOut.;
 set &dsOut._PostSummaries;
 where Parameter = 'indicator';
 Rej = ( Mean > &gamma.); 
run;
proc univariate data = &dsOut. noprint;
 var Rej;
 output out = &dsOut. mean=RejRate;
run;

data _temp_;
 set &dsIN.(obs=1);
 keep pi: n:;
run;

data &dsOut.;
 merge _temp_ &dsOut.;
 label RejRate = 'Empirical Null Hypothesis Rejection Rate';
run;

proc datasets library=work noprint; delete _temp_; run; quit;
%mend;
